==> jdk-11.0.29_windows-x64_bin.zip: jdk.security.auth/com/sun/security/auth/UnixNumericUserPrincipal.java <==
/*
 * Copyright (c) 2000, 2023, Oracle and/or its affiliates. All rights reserved.
 * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 */

package com.sun.security.auth;

import java.io.IOException;
import java.io.InvalidObjectException;
import java.io.ObjectInputStream;
import java.security.Principal;

/**
 * This class implements the {@code Principal} interface
 * and represents a user's Unix identification number (UID).
 *
 * <p> Principals such as this {@code UnixNumericUserPrincipal}
 * may be associated with a particular {@code Subject}
 * to augment that {@code Subject} with an additional
 * identity.  Refer to the {@code Subject} class for more information
 * on how to achieve this.  Authorization decisions can then be based upon
 * the Principals associated with a {@code Subject}.
 *
 * @see java.security.Principal
 * @see javax.security.auth.Subject
 */
public class UnixNumericUserPrincipal implements
                                        Principal,
                                        java.io.Serializable {
    private static final long serialVersionUID = -4329764253802397821L;

    /**
     * @serial
     */
    private String name;

    /**
     * Create a {@code UnixNumericUserPrincipal} using a
     * {@code String} representation of the
     * user's identification number (UID).
     *
     * @param name the user identification number (UID) for this user.
     *
     * @exception NullPointerException if the {@code name}
     *                  is {@code null}.
     */
    public UnixNumericUserPrincipal(String name) {
        if (name == null) {
            java.text.MessageFormat form = new java.text.MessageFormat
                (sun.security.util.ResourcesMgr.getAuthResourceString
                        ("invalid.null.input.value"));
            Object[] source = {"name"};
            throw new NullPointerException(form.format(source));
        }

        this.name = name;
    }

    /**
     * Create a {@code UnixNumericUserPrincipal} using a
     * long representation of the user's identification number (UID).
     *
     * @param name the user identification number (UID) for this user
     *                  represented as a long.
     */
    public UnixNumericUserPrincipal(long name) {
        this.name = Long.toString(name);
    }

    /**
     * Return the user identification number (UID) for this
     * {@code UnixNumericUserPrincipal}.
     *
     * @return the user identification number (UID) for this
     *          {@code UnixNumericUserPrincipal}
     */
    public String getName() {
        return name;
    }

    /**
     * Return the user identification number (UID) for this
     * {@code UnixNumericUserPrincipal} as a long.
     *
     * @return the user identification number (UID) for this
     *          {@code UnixNumericUserPrincipal} as a long.
     */
    public long longValue() {
        return Long.parseLong(name);
    }

    /**
     * Return a string representation of this
     * {@code UnixNumericUserPrincipal}.
     *
     * @return a string representation of this
     *          {@code UnixNumericUserPrincipal}.
     */
    public String toString() {
        java.text.MessageFormat form = new java.text.MessageFormat
                (sun.security.util.ResourcesMgr.getAuthResourceString
                        ("UnixNumericUserPrincipal.name"));
        Object[] source = {name};
        return form.format(source);
    }

    /**
     * Compares the specified Object with this
     * {@code UnixNumericUserPrincipal}
     * for equality.  Returns true if the given object is also a
     * {@code UnixNumericUserPrincipal} and the two
     * UnixNumericUserPrincipals
     * have the same user identification number (UID).
     *
     * @param o Object to be compared for equality with this
     *          {@code UnixNumericUserPrincipal}.
     *
     * @return true if the specified Object is equal to this
     *          {@code UnixNumericUserPrincipal}.
     */
    public boolean equals(Object o) {
        if (o == null)
            return false;

        if (this == o)
            return true;

        if (!(o instanceof UnixNumericUserPrincipal))
            return false;
        UnixNumericUserPrincipal that = (UnixNumericUserPrincipal)o;

        return this.getName().equals(that.getName());
    }

    /**
     * Return a hash code for this {@code UnixNumericUserPrincipal}.
     *
     * @return a hash code for this {@code UnixNumericUserPrincipal}.
     */
    public int hashCode() {
        return name.hashCode();
    }

    /**
     * Restores the state of this object from the stream.
     *
     * @param  stream the {@code ObjectInputStream} from which data is read
     * @throws IOException if an I/O error occurs
     * @throws ClassNotFoundException if a serialized class cannot be loaded
     */
    private void readObject(ObjectInputStream stream)
            throws IOException, ClassNotFoundException {
        stream.defaultReadObject();
        if (name == null) {
            java.text.MessageFormat form = new java.text.MessageFormat
                    (sun.security.util.ResourcesMgr.getAuthResourceString
                            ("invalid.null.input.value"));
            Object[] source = {"name"};
            throw new InvalidObjectException(form.format(source));
        }
    }
}

==> jdk-19.0.2_windows-x64_bin.zip: jdk.security.auth/com/sun/security/auth/UnixNumericUserPrincipal.java <==
/*
 * Copyright (c) 2000, 2013, Oracle and/or its affiliates. All rights reserved.
 * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 */

package com.sun.security.auth;

import java.security.Principal;

/**
 * This class implements the {@code Principal} interface
 * and represents a user's Unix identification number (UID).
 *
 * <p> Principals such as this {@code UnixNumericUserPrincipal}
 * may be associated with a particular {@code Subject}
 * to augment that {@code Subject} with an additional
 * identity.  Refer to the {@code Subject} class for more information
 * on how to achieve this.  Authorization decisions can then be based upon
 * the Principals associated with a {@code Subject}.
 *
 * @see java.security.Principal
 * @see javax.security.auth.Subject
 */
public class UnixNumericUserPrincipal implements
                                        Principal,
                                        java.io.Serializable {
    private static final long serialVersionUID = -4329764253802397821L;

    /**
     * @serial
     */
    private String name;

    /**
     * Create a {@code UnixNumericUserPrincipal} using a
     * {@code String} representation of the
     * user's identification number (UID).
     *
     * @param name the user identification number (UID) for this user.
     *
     * @exception NullPointerException if the {@code name}
     *                  is {@code null}.
     */
    public UnixNumericUserPrincipal(String name) {
        if (name == null) {
            java.text.MessageFormat form = new java.text.MessageFormat
                (sun.security.util.ResourcesMgr.getAuthResourceString
                        ("invalid.null.input.value"));
            Object[] source = {"name"};
            throw new NullPointerException(form.format(source));
        }

        this.name = name;
    }

    /**
     * Create a {@code UnixNumericUserPrincipal} using a
     * long representation of the user's identification number (UID).
     *
     * @param name the user identification number (UID) for this user
     *                  represented as a long.
     */
    public UnixNumericUserPrincipal(long name) {
        this.name = Long.toString(name);
    }

    /**
     * Return the user identification number (UID) for this
     * {@code UnixNumericUserPrincipal}.
     *
     * @return the user identification number (UID) for this
     *          {@code UnixNumericUserPrincipal}
     */
    public String getName() {
        return name;
    }

    /**
     * Return the user identification number (UID) for this
     * {@code UnixNumericUserPrincipal} as a long.
     *
     * @return the user identification number (UID) for this
     *          {@code UnixNumericUserPrincipal} as a long.
     */
    public long longValue() {
        return Long.parseLong(name);
    }

    /**
     * Return a string representation of this
     * {@code UnixNumericUserPrincipal}.
     *
     * @return a string representation of this
     *          {@code UnixNumericUserPrincipal}.
     */
    public String toString() {
        java.text.MessageFormat form = new java.text.MessageFormat
                (sun.security.util.ResourcesMgr.getAuthResourceString
                        ("UnixNumericUserPrincipal.name"));
        Object[] source = {name};
        return form.format(source);
    }

    /**
     * Compares the specified Object with this
     * {@code UnixNumericUserPrincipal}
     * for equality.  Returns true if the given object is also a
     * {@code UnixNumericUserPrincipal} and the two
     * UnixNumericUserPrincipals
     * have the same user identification number (UID).
     *
     * @param o Object to be compared for equality with this
     *          {@code UnixNumericUserPrincipal}.
     *
     * @return true if the specified Object is equal to this
     *          {@code UnixNumericUserPrincipal}.
     */
    public boolean equals(Object o) {
        if (o == null)
            return false;

        if (this == o)
            return true;

        if (!(o instanceof UnixNumericUserPrincipal))
            return false;
        UnixNumericUserPrincipal that = (UnixNumericUserPrincipal)o;

        if (this.getName().equals(that.getName()))
            return true;
        return false;
    }

    /**
     * Return a hash code for this {@code UnixNumericUserPrincipal}.
     *
     * @return a hash code for this {@code UnixNumericUserPrincipal}.
     */
    public int hashCode() {
        return name.hashCode();
    }
}
